@@ -6,9 +6,10 @@ use List::Util qw( first );
 use Log::Log4perl qw( :easy );
 use MojoX::Log::Log4perl;
 use File::ReadBackwards;
+use File::HomeDir;
 
 # ABSTRACT: A Log::Log4perl wrapper for use with Clustericious.
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 sub import {
@@ -35,9 +36,10 @@ sub init_logging {
     $Log::Log4perl::Logger::INITIALIZED = 0 if $initPid && $initPid != $$;
     $initPid = $$;
 
+    my $home = File::HomeDir->my_home;
     my @Confdirs = $harness_active ?
         ($ENV{CLUSTERICIOUS_TEST_CONF_DIR}) :
-        ($ENV{HOME}, "$ENV{HOME}/etc", "/util/etc", "/etc" );
+        ($home, "$home/etc", "/util/etc", "/etc" );
 
     # Logging
     $ENV{LOG_LEVEL} ||= ( $harness_active ? "WARN" : "DEBUG" );
@@ -116,7 +118,7 @@ Clustericious::Log - A Log::Log4perl wrapper for use with Clustericious.
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -135,7 +137,7 @@ for logging patterns (see the example).
 
 =head1 EXAMPLE
 
-Here is a sample $HOME/etc/log4perl.conf :
+Here is a sample ~/etc/log4perl.conf :
 
  log4perl.rootLogger=TRACE, LOGFILE
  log4perl.appender.LOGFILE=Log::Log4perl::Appender::File
@@ -152,7 +154,7 @@ Here is a sample $HOME/etc/log4perl.conf :
 =item init_logging
 
 Start logging.  Looks for log4perl.conf or $app.log4perl.conf
-in $HOME/etc, /util/etc and /etc.
+in ~/etc, /util/etc and /etc.
 
 =item tail
 
